@@ -358,7 +358,11 @@ class Index:
         if args == None:
             return AlgoliaUtils_request(self.client.headers, self.hosts, "GET", "/1/indexes/%s?query=%s" % (self.urlIndexName, quote(query.encode('utf8'))))
         else:
-            for k, v in args.iteritems():
+            try:
+                iteritems = args.iteritems(); #Python3.X Fix
+            except AttributeError:
+                iteritems = args.items();
+            for k, v in iteritems:
                 if isinstance(v, (list, tuple)):
                     args[k] = json.dumps(v)
                 else:
@@ -373,7 +377,7 @@ class Index:
                      Page is zero-based and defaults to 0. Thus, to retrieve the 10th page you need to set page=9
          @param hitsPerPage: Pagination parameter used to select the number of hits per page. Defaults to 1000.
         """
-        return AlgoliaUtils_request(self.sessions, "GET", "/1/indexes/%s/browse?page=%d&hitsPerPage=%d" % (self.urlIndexName, page, hitsPerPage))
+        return AlgoliaUtils_request(self.client.headers, self.hosts, "GET", "/1/indexes/%s/browse?page=%d&hitsPerPage=%d" % (self.urlIndexName, page, hitsPerPage))
 
     def waitTask(self, taskID, timeBeforeRetry = 100):
         """
@@ -507,7 +511,7 @@ def AlgoliaUtils_request(headers, hosts, method, request, body = None):
         try:
             obj = None
             if body != None:
-                obj = json.dumps(body, cls = JSONEncoderWithDatetime)
+                obj = json.dumps(body, cls = JSONEncoderWithDatetimeAndDefaultToString)
             conn = POOL_MANAGER.connection_from_host(host, scheme = 'https')
             answer  = conn.urlopen(method, request, headers = headers, body = obj)
             content = json.loads(answer.data.decode('utf-8'))
@@ -529,9 +533,11 @@ def AlgoliaUtils_request(headers, hosts, method, request, body = None):
     else:
         raise AlgoliaException("Unreachable host")
 
-class JSONEncoderWithDatetime(json.JSONEncoder):
+class JSONEncoderWithDatetimeAndDefaultToString(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, datetime.datetime):
             return int(time.mktime(obj.timetuple()))
-        return json.JSONEncoder.default(self, obj)
-
+        try:
+            return json.JSONEncoder.default(self, obj)
+        except:
+            return str(obj)
